#[repr(C)]pub struct SDL_AsyncIOOutcome {
pub asyncio: *mut SDL_AsyncIO,
pub type: SDL_AsyncIOTaskType,
pub result: SDL_AsyncIOResult,
pub buffer: *mut c_void,
pub offset: Uint64,
pub bytes_requested: Uint64,
pub bytes_transferred: Uint64,
pub userdata: *mut c_void,
}Expand description
Information about a completed asynchronous I/O request.
Availability
This struct is available since SDL 3.2.0.
Fields
asyncio: *mut SDL_AsyncIOwhat generated this task. This pointer will be invalid if it was closed!
type: SDL_AsyncIOTaskTypeWhat sort of task was this? Read, write, etc?
result: SDL_AsyncIOResultthe result of the work (success, failure, cancellation).
buffer: *mut c_voidbuffer where data was read/written.
offset: Uint64offset in the SDL_AsyncIO where data was read/written.
bytes_requested: Uint64number of bytes the task was to read/write.
bytes_transferred: Uint64actual number of bytes that were read/written.
userdata: *mut c_voidpointer provided by the app when starting the task