SDL_BindAudioStream

Function SDL_BindAudioStream 

pub unsafe extern "C" fn SDL_BindAudioStream(
    devid: SDL_AudioDeviceID,
    stream: *mut SDL_AudioStream,
) -> bool
Bind a single audio stream to an audio device.

This is a convenience function, equivalent to calling SDL_BindAudioStreams(devid, &stream, 1).

Parameters

  • devid: an audio device to bind a stream to.
  • stream: an audio stream to bind to a device.

Return value

Returns true on success or false on failure; call SDL_GetError() for more information.

Thread safety

It is safe to call this function from any thread.

Availability

This function is available since SDL 3.2.0.

See also