pub unsafe extern "C" fn SDL_DestroyAudioStream(
stream: *mut SDL_AudioStream,
)Expand description
Free an audio stream.
This will release all allocated data, including any audio that is still queued. You do not need to manually clear the stream first.
If this stream was bound to an audio device, it is unbound during this
call. If this stream was created with SDL_OpenAudioDeviceStream, the audio
device that was opened alongside this stream’s creation will be closed,
too.
Parameters
stream: the audio stream to destroy.
Thread safety
It is safe to call this function from any thread.
Availability
This function is available since SDL 3.2.0.