SDL_GetAudioFormatName

Function SDL_GetAudioFormatName 

pub unsafe extern "C" fn SDL_GetAudioFormatName(
    format: SDL_AudioFormat,
) -> *const c_char
Get the human readable name of an audio format.

Parameters

  • format: the audio format to query.

Return value

Returns the human readable name of the specified audio format or “SDL_AUDIO_UNKNOWN” if the format isn’t recognized.

Thread safety

It is safe to call this function from any thread.

Availability

This function is available since SDL 3.2.0.