pub unsafe extern "C" fn SDL_PutAudioStreamDataNoCopy(
stream: *mut SDL_AudioStream,
buf: *const c_void,
len: c_int,
callback: SDL_AudioStreamDataCompleteCallback,
userdata: *mut c_void,
) -> boolExpand description
Add external data to an audio stream without copying it.
Unlike SDL_PutAudioStreamData(), this function does not make a copy of the
provided data, instead storing the provided pointer. This means that the
put operation does not need to allocate and copy the data, but the original
data must remain available until the stream is done with it, either by
being read from the stream in its entirety, or a call to
SDL_ClearAudioStream() or SDL_DestroyAudioStream().
The data must match the format/channels/samplerate specified in the latest
call to SDL_SetAudioStreamFormat, or the format specified when creating the
stream if it hasn’t been changed.
An optional callback may be provided, which is called when the stream no longer needs the data. Once this callback fires, the stream will not access the data again. This callback will fire for any reason the data is no longer needed, including clearing or destroying the stream.
Note that there is still an allocation to store tracking information, so
this function is more efficient for larger blocks of data. If you’re
planning to put a few samples at a time, it will be more efficient to use
SDL_PutAudioStreamData(), which allocates and buffers in blocks.
Parameters
stream: the stream the audio data is being added to.buf: a pointer to the audio data to add.len: the number of bytes to add to the stream.callback: the callback function to call when the data is no longer needed by the stream. May be NULL.userdata: an opaque pointer provided to the callback for its own personal use.
Return value
Returns true on success or false on failure; call SDL_GetError() for more
information.
Thread safety
It is safe to call this function from any thread, but if the stream has a callback set, the caller might need to manage extra locking.
Availability
This function is available since SDL 3.4.0.