pub unsafe fn SDL_Unsupported() -> boolExpand description
A macro to standardize error reporting on unsupported operations.
This simply calls SDL_SetError() with a standardized error string, for
convenience, consistency, and clarity.
Thread safety
It is safe to call this macro from any thread.
Availability
This macro is available since SDL 3.2.0.