#[repr(C)]pub struct SDL_PenTouchEvent {
pub type: SDL_EventType,
pub reserved: Uint32,
pub timestamp: Uint64,
pub windowID: SDL_WindowID,
pub which: SDL_PenID,
pub pen_state: SDL_PenInputFlags,
pub x: c_float,
pub y: c_float,
pub eraser: bool,
pub down: bool,
}Expand description
Pressure-sensitive pen touched event structure (event.ptouch.*)
These events come when a pen touches a surface (a tablet, etc), or lifts off from one.
Availability
This struct is available since SDL 3.2.0.
Fields
type: SDL_EventTypereserved: Uint32timestamp: Uint64In nanoseconds, populated using SDL_GetTicksNS()
windowID: SDL_WindowIDThe window with pen focus, if any
which: SDL_PenIDThe pen instance id
pen_state: SDL_PenInputFlagsComplete pen input state at time of event
x: c_floatX coordinate, relative to window
y: c_floatY coordinate, relative to window
eraser: booltrue if eraser end is used (not all pens support this).
down: booltrue if the pen is touching or false if the pen is lifted off