SDL_TouchFingerEvent

Struct SDL_TouchFingerEvent 

#[repr(C)]
pub struct SDL_TouchFingerEvent { pub type: SDL_EventType, pub reserved: Uint32, pub timestamp: Uint64, pub touchID: SDL_TouchID, pub fingerID: SDL_FingerID, pub x: c_float, pub y: c_float, pub dx: c_float, pub dy: c_float, pub pressure: c_float, pub windowID: SDL_WindowID, }
Touch finger event structure (event.tfinger.*)

Coordinates in this event are normalized. x and y are normalized to a range between 0.0f and 1.0f, relative to the window, so (0,0) is the top left and (1,1) is the bottom right. Delta coordinates dx and dy are normalized in the ranges of -1.0f (traversed all the way from the bottom or right to all the way up or left) to 1.0f (traversed all the way from the top or left to all the way down or right).

Note that while the coordinates are normalized, they are not clamped, which means in some circumstances you can get a value outside of this range. For example, a renderer using logical presentation might give a negative value when the touch is in the letterboxing. Some platforms might report a touch outside of the window, which will also be outside of the range.

Availability

This struct is available since SDL 3.2.0.

Fields

type: SDL_EventTypereserved: Uint32timestamp: Uint64

In nanoseconds, populated using SDL_GetTicksNS()

touchID: SDL_TouchID

The touch device id

fingerID: SDL_FingerIDx: c_float

Normalized in the range 0…1

y: c_float

Normalized in the range 0…1

dx: c_float

Normalized in the range -1…1

dy: c_float

Normalized in the range -1…1

pressure: c_float

Normalized in the range 0…1

windowID: SDL_WindowID

The window underneath the finger, if any