pub unsafe extern "C" fn SDL_AddGamepadMappingsFromFile(
file: *const c_char,
) -> c_intExpand description
Load a set of gamepad mappings from a file.
You can call this function several times, if needed, to load different database files.
If a new mapping is loaded for an already known gamepad GUID, the later version will overwrite the one currently loaded.
Any new mappings for already plugged in controllers will generate
SDL_EVENT_GAMEPAD_ADDED events.
Mappings not belonging to the current platform or with no platform field specified will be ignored (i.e. mappings for Linux will be ignored in Windows, etc).
Parameters
file: the mappings file to load.
Return value
Returns the number of mappings added or -1 on failure; call SDL_GetError()
for more information.
Thread safety
It is safe to call this function from any thread.
Availability
This function is available since SDL 3.2.0.