SDL_GetGamepadButtonLabelForType

Function SDL_GetGamepadButtonLabelForType 

pub unsafe extern "C" fn SDL_GetGamepadButtonLabelForType(
    type: SDL_GamepadType,
    button: SDL_GamepadButton,
) -> SDL_GamepadButtonLabel
Get the label of a button on a gamepad.

Parameters

  • type: the type of gamepad to check.
  • button: a button index (one of the SDL_GamepadButton values).

Return value

Returns the SDL_GamepadButtonLabel enum corresponding to the button label.

Thread safety

It is safe to call this function from any thread.

Availability

This function is available since SDL 3.2.0.

See also