pub unsafe extern "C" fn SDL_GetGamepadStringForType(
type: SDL_GamepadType,
) -> *const c_charExpand description
Convert from an SDL_GamepadType enum to a string.
Parameters
type: an enum value for a givenSDL_GamepadType.
Return value
Returns a string for the given type, or NULL if an invalid type is
specified. The string returned is of the format used by
SDL_Gamepad mapping strings.
Thread safety
It is safe to call this function from any thread.
Availability
This function is available since SDL 3.2.0.