SDL_GPUTextureFormatTexelBlockSize

Function SDL_GPUTextureFormatTexelBlockSize 

pub unsafe extern "C" fn SDL_GPUTextureFormatTexelBlockSize(
    format: SDL_GPUTextureFormat,
) -> Uint32
Obtains the texel block size for a texture format.

Parameters

  • format: the texture format you want to know the texel size of.

Return value

Returns the texel block size of the texture format.

Availability

This function is available since SDL 3.2.0.

See also