pub unsafe extern "C" fn SDL_GetGPUSwapchainTextureFormat(
device: *mut SDL_GPUDevice,
window: *mut SDL_Window,
) -> SDL_GPUTextureFormatExpand description
Obtains the texture format of the swapchain for the given window.
Note that this format can change if the swapchain parameters change.
Parameters
device: a GPU context.window: anSDL_Windowthat has been claimed.
Return value
Returns the texture format of the swapchain.
Availability
This function is available since SDL 3.2.0.