SDL_SetGPUTextureName

Function SDL_SetGPUTextureName 

pub unsafe extern "C" fn SDL_SetGPUTextureName(
    device: *mut SDL_GPUDevice,
    texture: *mut SDL_GPUTexture,
    text: *const c_char,
)
Sets an arbitrary string constant to label a texture.

You should use SDL_PROP_GPU_TEXTURE_CREATE_NAME_STRING with SDL_CreateGPUTexture instead of this function to avoid thread safety issues.

Parameters

  • device: a GPU Context.
  • texture: a texture to attach the name to.
  • text: a UTF-8 string constant to mark as the name of the texture.

Thread safety

This function is not thread safe, you must make sure the texture is not simultaneously used by any other thread.

Availability

This function is available since SDL 3.2.0.

See also