SDL_GetMaxHapticEffects

Function SDL_GetMaxHapticEffects 

pub unsafe extern "C" fn SDL_GetMaxHapticEffects(
    haptic: *mut SDL_Haptic,
) -> c_int
Get the number of effects a haptic device can store.

On some platforms this isn’t fully supported, and therefore is an approximation. Always check to see if your created effect was actually created and do not rely solely on SDL_GetMaxHapticEffects().

Parameters

Return value

Returns the number of effects the haptic device can store or a negative error code on failure; call SDL_GetError() for more information.

Availability

This function is available since SDL 3.2.0.

See also