SDL_hid_read_timeout

Function SDL_hid_read_timeout 

pub unsafe extern "C" fn SDL_hid_read_timeout(
    dev: *mut SDL_hid_device,
    data: *mut c_uchar,
    length: usize,
    milliseconds: c_int,
) -> c_int
Read an Input report from a HID device with timeout.

Input reports are returned to the host through the INTERRUPT IN endpoint. The first byte will contain the Report number if the device uses numbered reports.

Parameters

  • dev: a device handle returned from SDL_hid_open().
  • data: a buffer to put the read data into.
  • length: the number of bytes to read. For devices with multiple reports, make sure to read an extra byte for the report number.
  • milliseconds: timeout in milliseconds or -1 for blocking wait.

Return value

Returns the actual number of bytes read and -1 on on failure; call SDL_GetError() for more information. If no packet was available to be read within the timeout period, this function returns 0.

Availability

This function is available since SDL 3.2.0.