SDL_GetHintBoolean

Function SDL_GetHintBoolean 

pub unsafe extern "C" fn SDL_GetHintBoolean(
    name: *const c_char,
    default_value: bool,
) -> bool
Get the boolean value of a hint variable.

Parameters

  • name: the name of the hint to get the boolean value from.
  • default_value: the value to return if the hint does not exist.

Return value

Returns the boolean value of a hint or the provided default value if the hint does not exist.

Thread safety

It is safe to call this function from any thread.

Availability

This function is available since SDL 3.2.0.

See also