SDL_ResetHints

Function SDL_ResetHints 

pub unsafe extern "C" fn SDL_ResetHints()
Reset all hints to the default values.

This will reset all hints to the value of the associated environment variable, or NULL if the environment isn’t set. Callbacks will be called normally with this change.

Thread safety

It is safe to call this function from any thread.

Availability

This function is available since SDL 3.2.0.

See also