SDL_SetHint

Function SDL_SetHint 

pub unsafe extern "C" fn SDL_SetHint(
    name: *const c_char,
    value: *const c_char,
) -> bool
Set a hint with normal priority.

Hints will not be set if there is an existing override hint or environment variable that takes precedence. You can use SDL_SetHintWithPriority() to set the hint with override priority instead.

Parameters

  • name: the hint to set.
  • value: the value of the hint variable.

Return value

Returns true on success or false on failure; call SDL_GetError() for more information.

Thread safety

It is safe to call this function from any thread.

Availability

This function is available since SDL 3.2.0.

See also