SDL_AppQuit_func

Type Alias SDL_AppQuit_func 

pub type SDL_AppQuit_func = Option<unsafe extern "C" fn(appstate: *mut c_void, result: SDL_AppResult)>;
Function pointer typedef for SDL_AppQuit.

These are used by SDL_EnterAppMainCallbacks. This mechanism operates behind the scenes for apps using the optional main callbacks. Apps that want to use this should just implement SDL_AppEvent directly.

Parameters

  • appstate: an optional pointer, provided by the app in SDL_AppInit.
  • result: the result code that terminated the app (success or failure).

Availability

This datatype is available since SDL 3.2.0.

Aliased Type

pub enum SDL_AppQuit_func {
    None,
    Some(unsafe extern "C" fn(*mut c_void, SDL_AppResult)),
}

Variants

1.0.0

None

No value.

1.0.0

Some(unsafe extern "C" fn(*mut c_void, SDL_AppResult))

Some value of type T.