SDL_GetModState

Function SDL_GetModState 

pub unsafe extern "C" fn SDL_GetModState() -> SDL_Keymod
Get the current key modifier state for the keyboard.

Return value

Returns an OR’d combination of the modifier keys for the keyboard.

Thread safety

It is safe to call this function from any thread.

Availability

This function is available since SDL 3.2.0.

See also