pub unsafe extern "C" fn SDL_GetTextInputArea(
window: *mut SDL_Window,
rect: *mut SDL_Rect,
cursor: *mut c_int,
) -> boolExpand description
Get the area used to type Unicode text input.
This returns the values previously set by SDL_SetTextInputArea().
Parameters
window: the window for which to query the text input area.rect: a pointer to anSDL_Rectfilled in with the text input area, may be NULL.cursor: a pointer to the offset of the current cursor location relative torect->x, may be NULL.
Return value
Returns true on success or false on failure; call SDL_GetError() for more
information.
Thread safety
This function should only be called on the main thread.
Availability
This function is available since SDL 3.2.0.