SDL_TextInputActive

Function SDL_TextInputActive 

pub unsafe extern "C" fn SDL_TextInputActive(
    window: *mut SDL_Window,
) -> bool
Check whether or not Unicode text input events are enabled for a window.

Parameters

  • window: the window to check.

Return value

Returns true if text input events are enabled else false.

Thread safety

This function should only be called on the main thread.

Availability

This function is available since SDL 3.2.0.

See also