SDL_UnloadObject

Function SDL_UnloadObject 

pub unsafe extern "C" fn SDL_UnloadObject(
    handle: *mut SDL_SharedObject,
)
Unload a shared object from memory.

Note that any pointers from this object looked up through SDL_LoadFunction() will no longer be valid.

Parameters

Thread safety

It is safe to call this function from any thread.

Availability

This function is available since SDL 3.2.0.

See also