SDL_GetCursor

Function SDL_GetCursor 

pub unsafe extern "C" fn SDL_GetCursor() -> *mut SDL_Cursor
Get the active cursor.

This function returns a pointer to the current cursor which is owned by the library. It is not necessary to free the cursor with SDL_DestroyCursor().

Return value

Returns the active cursor or NULL if there is no mouse.

Thread safety

This function should only be called on the main thread.

Availability

This function is available since SDL 3.2.0.

See also