pub unsafe extern "C" fn SDL_CreateMutex() -> *mut SDL_MutexExpand description
Create a new mutex.
All newly-created mutexes begin in the unlocked state.
Calls to SDL_LockMutex() will not return while the mutex is locked by
another thread. See SDL_TryLockMutex() to attempt to lock without blocking.
SDL mutexes are reentrant.
Return value
Returns the initialized and unlocked mutex or NULL on failure; call
SDL_GetError() for more information.
Thread safety
It is safe to call this function from any thread.
Availability
This function is available since SDL 3.2.0.