SDL_ShouldInit

Function SDL_ShouldInit 

pub unsafe extern "C" fn SDL_ShouldInit(
    state: *mut SDL_InitState,
) -> bool
Return whether initialization should be done.

This function checks the passed in state and if initialization should be done, sets the status to SDL_INIT_STATUS_INITIALIZING and returns true. If another thread is already modifying this state, it will wait until that’s done before returning.

If this function returns true, the calling code must call SDL_SetInitialized() to complete the initialization.

Parameters

  • state: the initialization state to check.

Return value

Returns true if initialization needs to be done, false otherwise.

Thread safety

It is safe to call this function from any thread.

Availability

This function is available since SDL 3.2.0.

See also