SDL_TryLockRWLockForWriting

Function SDL_TryLockRWLockForWriting 

pub unsafe extern "C" fn SDL_TryLockRWLockForWriting(
    rwlock: *mut SDL_RWLock,
) -> bool
Try to lock a read/write lock for writing without blocking.

This works just like SDL_LockRWLockForWriting(), but if the rwlock is not available, then this function returns false immediately.

This technique is useful if you need exclusive access to a resource but don’t want to wait for it, and will return to it to try again later.

It is illegal for the owning thread to lock an already-locked rwlock for writing (read-only may be locked recursively, writing can not). Doing so results in undefined behavior.

It is illegal to request a write lock from a thread that already holds a read-only lock. Doing so results in undefined behavior. Unlock the read-only lock before requesting a write lock.

This function returns true if passed a NULL rwlock.

Parameters

  • rwlock: the rwlock to try to lock.

Return value

Returns true on success, false if the lock would block.

Thread safety

It is safe to call this function from any thread.

Availability

This function is available since SDL 3.2.0.

See also