pub struct SDL_Semaphore { /* private fields */ }Expand description
A means to manage access to a resource, by count, between threads.
Semaphores (specifically, “counting semaphores”), let X number of threads request access at the same time, each thread granted access decrementing a counter. When the counter reaches zero, future requests block until a prior thread releases their request, incrementing the counter again.
Wikipedia has a thorough explanation of the concept:
https://en.wikipedia.org/wiki/Semaphore_(programming)
Availability
This struct is available since SDL 3.2.0.