SDL_GetPixelFormatName

Function SDL_GetPixelFormatName 

pub extern "C" fn SDL_GetPixelFormatName(
    format: SDL_PixelFormat,
) -> *const c_char
Get the human readable name of a pixel format.

Parameters

  • format: the pixel format to query.

Return value

Returns the human readable name of the specified pixel format or “SDL_PIXELFORMAT_UNKNOWN” if the format isn’t recognized.

Thread safety

It is safe to call this function from any thread.

Availability

This function is available since SDL 3.2.0.