SDL_SetPointerProperty

Function SDL_SetPointerProperty 

pub unsafe extern "C" fn SDL_SetPointerProperty(
    props: SDL_PropertiesID,
    name: *const c_char,
    value: *mut c_void,
) -> bool
Set a pointer property in a group of properties.

Parameters

  • props: the properties to modify.
  • name: the name of the property to modify.
  • value: the new value of the property, or NULL to delete the property.

Return value

Returns true on success or false on failure; call SDL_GetError() for more information.

Thread safety

It is safe to call this function from any thread.

Availability

This function is available since SDL 3.2.0.

See also