SDL_EnumeratePropertiesCallback

Type Alias SDL_EnumeratePropertiesCallback 

pub type SDL_EnumeratePropertiesCallback = Option<unsafe extern "C" fn(userdata: *mut c_void, props: SDL_PropertiesID, name: *const c_char)>;
A callback used to enumerate all the properties in a group of properties.

This callback is called from SDL_EnumerateProperties(), and is called once per property in the set.

Parameters

  • userdata: an app-defined pointer passed to the callback.
  • props: the SDL_PropertiesID that is being enumerated.
  • name: the next property name in the enumeration.

Thread safety

SDL_EnumerateProperties holds a lock on props during this callback.

Availability

This datatype is available since SDL 3.2.0.

See also

Aliased Type

pub enum SDL_EnumeratePropertiesCallback {
    None,
    Some(unsafe extern "C" fn(*mut c_void, SDL_PropertiesID, *const i8)),
}

Variants

1.0.0

None

No value.

1.0.0

Some(unsafe extern "C" fn(*mut c_void, SDL_PropertiesID, *const i8))

Some value of type T.