SDL_GetRectAndLineIntersectionFloat

Function SDL_GetRectAndLineIntersectionFloat 

pub unsafe extern "C" fn SDL_GetRectAndLineIntersectionFloat(
    rect: *const SDL_FRect,
    X1: *mut c_float,
    Y1: *mut c_float,
    X2: *mut c_float,
    Y2: *mut c_float,
) -> bool
Calculate the intersection of a rectangle and line segment with float precision.

This function is used to clip a line segment to a rectangle. A line segment contained entirely within the rectangle or that does not intersect will remain unchanged. A line segment that crosses the rectangle at either or both ends will be clipped to the boundary of the rectangle and the new coordinates saved in X1, Y1, X2, and/or Y2 as necessary.

Parameters

  • rect: an SDL_FRect structure representing the rectangle to intersect.
  • X1: a pointer to the starting X-coordinate of the line.
  • Y1: a pointer to the starting Y-coordinate of the line.
  • X2: a pointer to the ending X-coordinate of the line.
  • Y2: a pointer to the ending Y-coordinate of the line.

Return value

Returns true if there is an intersection, false otherwise.

Thread safety

It is safe to call this function from any thread.

Availability

This function is available since SDL 3.2.0.