pub unsafe extern "C" fn SDL_GetRectIntersection(
A: *const SDL_Rect,
B: *const SDL_Rect,
result: *mut SDL_Rect,
) -> boolExpand description
Calculate the intersection of two rectangles.
If result is NULL then this function will return false.
Parameters
A: anSDL_Rectstructure representing the first rectangle.B: anSDL_Rectstructure representing the second rectangle.result: anSDL_Rectstructure filled in with the intersection of rectanglesAandB.
Return value
Returns true if there is an intersection, false otherwise.
Thread safety
It is safe to call this function from any thread.
Availability
This function is available since SDL 3.2.0.