SDL_HasRectIntersectionFloat

Function SDL_HasRectIntersectionFloat 

pub unsafe extern "C" fn SDL_HasRectIntersectionFloat(
    A: *const SDL_FRect,
    B: *const SDL_FRect,
) -> bool
Determine whether two rectangles intersect with float precision.

If either pointer is NULL the function will return false.

Parameters

  • A: an SDL_FRect structure representing the first rectangle.
  • B: an SDL_FRect structure representing the second rectangle.

Return value

Returns true if there is an intersection, false otherwise.

Thread safety

It is safe to call this function from any thread.

Availability

This function is available since SDL 3.2.0.

See also