SDL_RenderClear

Function SDL_RenderClear 

pub unsafe extern "C" fn SDL_RenderClear(
    renderer: *mut SDL_Renderer,
) -> bool
Clear the current rendering target with the drawing color.

This function clears the entire rendering target, ignoring the viewport and the clip rectangle. Note, that clearing will also set/fill all pixels of the rendering target to current renderer draw color, so make sure to invoke SDL_SetRenderDrawColor() when needed.

Parameters

  • renderer: the rendering context.

Return value

Returns true on success or false on failure; call SDL_GetError() for more information.

Thread safety

This function should only be called on the main thread.

Availability

This function is available since SDL 3.2.0.

See also