SDL_RenderPoint

Function SDL_RenderPoint 

pub unsafe extern "C" fn SDL_RenderPoint(
    renderer: *mut SDL_Renderer,
    x: c_float,
    y: c_float,
) -> bool
Draw a point on the current rendering target at subpixel precision.

Parameters

  • renderer: the renderer which should draw a point.
  • x: the x coordinate of the point.
  • y: the y coordinate of the point.

Return value

Returns true on success or false on failure; call SDL_GetError() for more information.

Thread safety

This function should only be called on the main thread.

Availability

This function is available since SDL 3.2.0.

See also