pub unsafe extern "C" fn SDL_RenderPoints(
renderer: *mut SDL_Renderer,
points: *const SDL_FPoint,
count: c_int,
) -> boolExpand description
Draw multiple points on the current rendering target at subpixel precision.
Parameters
renderer: the renderer which should draw multiple points.points: the points to draw.count: the number of points to draw.
Return value
Returns true on success or false on failure; call SDL_GetError() for more
information.
Thread safety
This function should only be called on the main thread.
Availability
This function is available since SDL 3.2.0.