pub unsafe extern "C" fn SDL_RenderTextureAffine(
renderer: *mut SDL_Renderer,
texture: *mut SDL_Texture,
srcrect: *const SDL_FRect,
origin: *const SDL_FPoint,
right: *const SDL_FPoint,
down: *const SDL_FPoint,
) -> boolExpand description
Copy a portion of the source texture to the current rendering target, with affine transform, at subpixel precision.
Parameters
renderer: the renderer which should copy parts of a texture.texture: the source texture.srcrect: a pointer to the source rectangle, or NULL for the entire texture.origin: a pointer to a point indicating where the top-left corner of srcrect should be mapped to, or NULL for the rendering target’s origin.right: a pointer to a point indicating where the top-right corner of srcrect should be mapped to, or NULL for the rendering target’s top-right corner.down: a pointer to a point indicating where the bottom-left corner of srcrect should be mapped to, or NULL for the rendering target’s bottom-left corner.
Return value
Returns true on success or false on failure; call SDL_GetError() for more
information.
Thread safety
You may only call this function from the main thread.
Availability
This function is available since SDL 3.2.0.