SDL_getenv

Function SDL_getenv 

pub unsafe extern "C" fn SDL_getenv(
    name: *const c_char,
) -> *const c_char
Get the value of a variable in the environment.

The name of the variable is case sensitive on all platforms.

This function uses SDL’s cached copy of the environment and is thread-safe.

Parameters

  • name: the name of the variable to get.

Return value

Returns a pointer to the value of the variable or NULL if it can’t be found.

Thread safety

It is safe to call this function from any thread.

Availability

This function is available since SDL 3.2.0.