SDL_isupper

Function SDL_isupper 

pub extern "C" fn SDL_isupper(x: c_int) -> c_int
Report if a character is upper case.

WARNING: Regardless of system locale, this will only treat ASCII values ‘A’ through ‘Z’ as true.

Parameters

  • x: character value to check.

Return value

Returns non-zero if x falls within the character class, zero otherwise.

Thread safety

It is safe to call this function from any thread.

Availability

This function is available since SDL 3.2.0.