pub extern "C" fn SDL_log(x: c_double) -> c_doubleExpand description
Compute the natural logarithm of x.
Domain: 0 < x <= INF
Range: -INF <= y <= INF
It is an error for x to be less than or equal to 0.
This function operates on double-precision floating point values, use
SDL_logf for single-precision floats.
This function may use a different approximation across different versions, platforms and configurations. i.e, it can return a different value given the same input on different machines or operating systems, or if SDL is updated.
Parameters
x: floating point value. Must be greater than 0.
Return value
Returns the natural logarithm of x.
Thread safety
It is safe to call this function from any thread.
Availability
This function is available since SDL 3.2.0.