SDL_memcmp

Function SDL_memcmp 

pub unsafe extern "C" fn SDL_memcmp(
    s1: *const c_void,
    s2: *const c_void,
    len: usize,
) -> c_int
Compare two buffers of memory.

Parameters

  • s1: the first buffer to compare. NULL is not permitted!
  • s2: the second buffer to compare. NULL is not permitted!
  • len: the number of bytes to compare between the buffers.

Return value

Returns less than zero if s1 is “less than” s2, greater than zero if s1 is “greater than” s2, and zero if the buffers match exactly for len bytes.

Thread safety

It is safe to call this function from any thread.

Availability

This function is available since SDL 3.2.0.