pub unsafe extern "C" fn SDL_memset(
dst: *mut c_void,
c: c_int,
len: usize,
) -> *mut c_voidExpand description
Initialize all bytes of buffer of memory to a specific value.
This function will set len bytes, pointed to by dst, to the value
specified in c.
Despite c being an int instead of a char, this only operates on
bytes; c must be a value between 0 and 255, inclusive.
Parameters
dst: the destination memory region. Must not be NULL.c: the byte value to set.len: the length, in bytes, to set indst.
Return value
Returns dst.
Thread safety
It is safe to call this function from any thread.
Availability
This function is available since SDL 3.2.0.