SDL_modff

Function SDL_modff 

pub unsafe extern "C" fn SDL_modff(
    x: c_float,
    y: *mut c_float,
) -> c_float
Split x into integer and fractional parts

This function operates on single-precision floating point values, use SDL_modf for double-precision floats.

Parameters

  • x: floating point value.
  • y: output pointer to store the integer part of x.

Return value

Returns the fractional part of x.

Thread safety

It is safe to call this function from any thread.

Availability

This function is available since SDL 3.2.0.

See also