SDL_rand_bits

Function SDL_rand_bits 

pub unsafe extern "C" fn SDL_rand_bits() -> Uint32
Generate 32 pseudo-random bits.

You likely want to use SDL_rand() to get a psuedo-random number instead.

There are no guarantees as to the quality of the random sequence produced, and this should not be used for security (cryptography, passwords) or where money is on the line (loot-boxes, casinos). There are many random number libraries available with different characteristics and you should pick one of those to meet any serious needs.

Return value

Returns a random value in the range of [0-SDL_MAX_UINT32].

Thread safety

All calls should be made from a single thread

Availability

This function is available since SDL 3.2.0.

See also