pub extern "C" fn SDL_sin(x: c_double) -> c_doubleExpand description
Compute the sine of x.
Domain: -INF <= x <= INF
Range: -1 <= y <= 1
This function operates on double-precision floating point values, use
SDL_sinf for single-precision floats.
This function may use a different approximation across different versions, platforms and configurations. i.e, it can return a different value given the same input on different machines or operating systems, or if SDL is updated.
Parameters
x: floating point value, in radians.
Return value
Returns sine of x.
Thread safety
It is safe to call this function from any thread.
Availability
This function is available since SDL 3.2.0.