SDL_strcmp

Function SDL_strcmp 

pub unsafe extern "C" fn SDL_strcmp(
    str1: *const c_char,
    str2: *const c_char,
) -> c_int
Compare two null-terminated UTF-8 strings.

Due to the nature of UTF-8 encoding, this will work with Unicode strings, since effectively this function just compares bytes until it hits a null-terminating character. Also due to the nature of UTF-8, this can be used with SDL_qsort() to put strings in (roughly) alphabetical order.

Parameters

  • str1: the first string to compare. NULL is not permitted!
  • str2: the second string to compare. NULL is not permitted!

Return value

Returns less than zero if str1 is “less than” str2, greater than zero if str1 is “greater than” str2, and zero if the strings match exactly.

Thread safety

It is safe to call this function from any thread.

Availability

This function is available since SDL 3.2.0.