SDL_vswprintf

Function SDL_vswprintf 

pub unsafe extern "C" fn SDL_vswprintf(
    text: *mut c_wchar_t,
    maxlen: usize,
    fmt: *const c_wchar_t,
    ap: VaList,
) -> c_int
This works exactly like vswprintf() but doesn’t require access to a C runtime.

Functions identically to SDL_swprintf(), except it takes a va_list instead of using ... variable arguments.

Parameters

  • text: the buffer to write the string into. Must not be NULL.
  • maxlen: the maximum wide characters to write, including the null-terminator.
  • fmt: a printf-style format wide string. Must not be NULL.
  • ap: a va_list values to be used with the format string.

Return value

Returns the number of wide characters that should be written, not counting the null-terminator char, or a negative value on error.

Thread safety

It is safe to call this function from any thread.

Availability

This function is available since SDL 3.2.0.