pub unsafe extern "C" fn SDL_FillSurfaceRect(
dst: *mut SDL_Surface,
rect: *const SDL_Rect,
color: Uint32,
) -> boolExpand description
Perform a fast fill of a rectangle with a specific color.
color should be a pixel of the format used by the surface, and can be
generated by SDL_MapRGB() or SDL_MapRGBA(). If the color value contains an
alpha component then the destination is simply filled with that alpha
information, no blending takes place.
If there is a clip rectangle set on the destination (set via
SDL_SetSurfaceClipRect()), then this function will fill based on the
intersection of the clip rectangle and rect.
Parameters
dst: theSDL_Surfacestructure that is the drawing target.rect: theSDL_Rectstructure representing the rectangle to fill, or NULL to fill the entire surface.color: the color to fill with.
Return value
Returns true on success or false on failure; call SDL_GetError() for more
information.
Thread safety
This function can be called on different threads with different surfaces.
Availability
This function is available since SDL 3.2.0.