pub unsafe extern "C" fn SDL_LoadBMP_IO(
src: *mut SDL_IOStream,
closeio: bool,
) -> *mut SDL_SurfaceExpand description
Load a BMP image from a seekable SDL data stream.
The new surface should be freed with SDL_DestroySurface(). Not doing so
will result in a memory leak.
Parameters
src: the data stream for the surface.closeio: if true, callsSDL_CloseIO()onsrcbefore returning, even in the case of an error.
Return value
Returns a pointer to a new SDL_Surface structure or NULL on failure; call
SDL_GetError() for more information.
Thread safety
It is safe to call this function from any thread.
Availability
This function is available since SDL 3.2.0.