SDL_LoadPNG

Function SDL_LoadPNG 

pub unsafe extern "C" fn SDL_LoadPNG(
    file: *const c_char,
) -> *mut SDL_Surface
Load a PNG image from a file.

This is intended as a convenience function for loading images from trusted sources. If you want to load arbitrary images you should use libpng or another image loading library designed with security in mind.

The new surface should be freed with SDL_DestroySurface(). Not doing so will result in a memory leak.

Parameters

  • file: the PNG file to load.

Return value

Returns a pointer to a new SDL_Surface structure or NULL on failure; call SDL_GetError() for more information.

Thread safety

It is safe to call this function from any thread.

Availability

This function is available since SDL 3.4.0.

See also