SDL_LoadSurface

Function SDL_LoadSurface 

pub unsafe extern "C" fn SDL_LoadSurface(
    file: *const c_char,
) -> *mut SDL_Surface
Load a BMP or PNG image from a file.

The new surface should be freed with SDL_DestroySurface(). Not doing so will result in a memory leak.

Parameters

  • file: the file to load.

Return value

Returns a pointer to a new SDL_Surface structure or NULL on failure; call SDL_GetError() for more information.

Thread safety

It is safe to call this function from any thread.

Availability

This function is available since SDL 3.4.0.

See also