SDL_LoadSurface_IO

Function SDL_LoadSurface_IO 

pub unsafe extern "C" fn SDL_LoadSurface_IO(
    src: *mut SDL_IOStream,
    closeio: bool,
) -> *mut SDL_Surface
Load a BMP or PNG image from a seekable SDL data stream.

The new surface should be freed with SDL_DestroySurface(). Not doing so will result in a memory leak.

Parameters

  • src: the data stream for the surface.
  • closeio: if true, calls SDL_CloseIO() on src before returning, even in the case of an error.

Return value

Returns a pointer to a new SDL_Surface structure or NULL on failure; call SDL_GetError() for more information.

Thread safety

It is safe to call this function from any thread.

Availability

This function is available since SDL 3.4.0.

See also