SDL_LockSurface

Function SDL_LockSurface 

pub unsafe extern "C" fn SDL_LockSurface(
    surface: *mut SDL_Surface,
) -> bool
Set up a surface for directly accessing the pixels.

Between calls to SDL_LockSurface() / SDL_UnlockSurface(), you can write to and read from surface->pixels, using the pixel format stored in surface->format. Once you are done accessing the surface, you should use SDL_UnlockSurface() to release it.

Not all surfaces require locking. If SDL_MUSTLOCK(surface) evaluates to 0, then you can read and write to the surface at any time, and the pixel format of the surface will not change.

Parameters

Return value

Returns true on success or false on failure; call SDL_GetError() for more information.

Thread safety

This function can be called on different threads with different surfaces. The locking referred to by this function is making the pixels available for direct access, not thread-safe locking.

Availability

This function is available since SDL 3.2.0.

See also