pub unsafe extern "C" fn SDL_SaveBMP(
surface: *mut SDL_Surface,
file: *const c_char,
) -> boolExpand description
Save a surface to a file in BMP format.
Surfaces with a 24-bit, 32-bit and paletted 8-bit format get saved in the BMP directly. Other RGB formats with 8-bit or higher get converted to a 24-bit surface or, if they have an alpha mask or a colorkey, to a 32-bit surface before they are saved. YUV and paletted 1-bit and 4-bit formats are not supported.
Parameters
surface: theSDL_Surfacestructure containing the image to be saved.file: a file to save to.
Return value
Returns true on success or false on failure; call SDL_GetError() for more
information.
Thread safety
This function can be called on different threads with different surfaces.
Availability
This function is available since SDL 3.2.0.