pub unsafe extern "C" fn SDL_SetWindowsMessageHook(
callback: SDL_WindowsMessageHook,
userdata: *mut c_void,
)Expand description
Set a callback for every Windows message, run before TranslateMessage().
The callback may modify the message, and should return true if the message should continue to be processed, or false to prevent further processing.
Parameters
callback: theSDL_WindowsMessageHookfunction to call.userdata: a pointer to pass to every iteration ofcallback.
Thread safety
This function should only be called on the main thread.
Availability
This function is available since SDL 3.2.0.