SDL_SetiOSEventPump

Function SDL_SetiOSEventPump 

pub unsafe extern "C" fn SDL_SetiOSEventPump(enabled: bool)
Use this function to enable or disable the SDL event pump on Apple iOS.

This function is only available on Apple iOS.

Parameters

  • enabled: true to enable the event pump, false to disable it.

Thread safety

This function should only be called on the main thread.

Availability

This function is available since SDL 3.2.0.

See also