SDL_GetThreadID

Function SDL_GetThreadID 

pub unsafe extern "C" fn SDL_GetThreadID(
    thread: *mut SDL_Thread,
) -> SDL_ThreadID
Get the thread identifier for the specified thread.

This thread identifier is as reported by the underlying operating system. If SDL is running on a platform that does not support threads the return value will always be zero.

Parameters

  • thread: the thread to query.

Return value

Returns the ID of the specified thread, or the ID of the current thread if thread is NULL.

Thread safety

It is safe to call this function from any thread.

Availability

This function is available since SDL 3.2.0.

See also