pub unsafe extern "C" fn SDL_GetCurrentTime(
ticks: *mut SDL_Time,
) -> boolExpand description
Gets the current value of the system realtime clock in nanoseconds since Jan 1, 1970 in Universal Coordinated Time (UTC).
Parameters
ticks: theSDL_Timeto hold the returned tick count.
Return value
Returns true on success or false on failure; call SDL_GetError() for more
information.
Thread safety
It is safe to call this function from any thread.
Availability
This function is available since SDL 3.2.0.