pub unsafe extern "C" fn SDL_TimeToDateTime(
ticks: SDL_Time,
dt: *mut SDL_DateTime,
localTime: bool,
) -> boolExpand description
Converts an SDL_Time in nanoseconds since the epoch to a calendar time in
the SDL_DateTime format.
Parameters
ticks: theSDL_Timeto be converted.dt: the resultingSDL_DateTime.localTime: the resultingSDL_DateTimewill be expressed in local time if true, otherwise it will be in Universal Coordinated Time (UTC).
Return value
Returns true on success or false on failure; call SDL_GetError() for more
information.
Thread safety
It is safe to call this function from any thread.
Availability
This function is available since SDL 3.2.0.