SDL_TimeToWindows

Function SDL_TimeToWindows 

pub unsafe extern "C" fn SDL_TimeToWindows(
    ticks: SDL_Time,
    dwLowDateTime: *mut Uint32,
    dwHighDateTime: *mut Uint32,
)
Converts an SDL time into a Windows FILETIME (100-nanosecond intervals since January 1, 1601).

This function fills in the two 32-bit values of the FILETIME structure.

Parameters

  • ticks: the time to convert.
  • dwLowDateTime: a pointer filled in with the low portion of the Windows FILETIME value.
  • dwHighDateTime: a pointer filled in with the high portion of the Windows FILETIME value.

Thread safety

It is safe to call this function from any thread.

Availability

This function is available since SDL 3.2.0.