SDL_GetVersion

Function SDL_GetVersion 

pub extern "C" fn SDL_GetVersion() -> c_int
Get the version of SDL that is linked against your program.

If you are linking to SDL dynamically, then it is possible that the current version will be different than the version you compiled against. This function returns the current version, while SDL_VERSION is the version you compiled with.

This function may be called safely at any time, even before SDL_Init().

Return value

Returns the version of the linked library.

Thread safety

It is safe to call this function from any thread.

Availability

This function is available since SDL 3.2.0.

See also