SDL_FlashWindow

Function SDL_FlashWindow 

pub unsafe extern "C" fn SDL_FlashWindow(
    window: *mut SDL_Window,
    operation: SDL_FlashOperation,
) -> bool
Request a window to demand attention from the user.

Parameters

  • window: the window to be flashed.
  • operation: the operation to perform.

Return value

Returns true on success or false on failure; call SDL_GetError() for more information.

Thread safety

This function should only be called on the main thread.

Availability

This function is available since SDL 3.2.0.