pub unsafe extern "C" fn SDL_GetDisplayForRect(
rect: *const SDL_Rect,
) -> SDL_DisplayIDExpand description
Get the display primarily containing a rect.
Parameters
rect: the rect to query.
Return value
Returns the instance ID of the display entirely containing the rect or
closest to the center of the rect on success or 0 on failure; call
SDL_GetError() for more information.
Thread safety
This function should only be called on the main thread.
Availability
This function is available since SDL 3.2.0.