SDL_GetWindowKeyboardGrab

Function SDL_GetWindowKeyboardGrab 

pub unsafe extern "C" fn SDL_GetWindowKeyboardGrab(
    window: *mut SDL_Window,
) -> bool
Get a window’s keyboard grab mode.

Parameters

  • window: the window to query.

Return value

Returns true if keyboard is grabbed, and false otherwise.

Thread safety

This function should only be called on the main thread.

Availability

This function is available since SDL 3.2.0.

See also