pub unsafe extern "C" fn SDL_SetWindowFocusable(
window: *mut SDL_Window,
focusable: bool,
) -> boolExpand description
Set whether the window may have input focus.
Parameters
window: the window to set focusable state.focusable: true to allow input focus, false to not allow input focus.
Return value
Returns true on success or false on failure; call SDL_GetError() for more
information.
Thread safety
This function should only be called on the main thread.
Availability
This function is available since SDL 3.2.0.