pub unsafe extern "C" fn SDL_SetWindowMouseGrab(
window: *mut SDL_Window,
grabbed: bool,
) -> boolExpand description
Set a window’s mouse grab mode.
Mouse grab confines the mouse cursor to the window.
Parameters
window: the window for which the mouse grab mode should be set.grabbed: this is true to grab mouse, and false to release.
Return value
Returns true on success or false on failure; call SDL_GetError() for more
information.
Thread safety
This function should only be called on the main thread.
Availability
This function is available since SDL 3.2.0.