pub unsafe extern "C" fn SDL_Vulkan_CreateSurface(
window: *mut SDL_Window,
instance: VkInstance,
allocator: *const VkAllocationCallbacks,
surface: *mut VkSurfaceKHR,
) -> boolExpand description
Create a Vulkan rendering surface for a window.
The window must have been created with the SDL_WINDOW_VULKAN flag and
instance must have been created with extensions returned by
SDL_Vulkan_GetInstanceExtensions() enabled.
If allocator is NULL, Vulkan will use the system default allocator. This
argument is passed directly to Vulkan and isn’t used by SDL itself.
Parameters
window: the window to which to attach the Vulkan surface.instance: the Vulkan instance handle.allocator: a VkAllocationCallbacks struct, which lets the app set the allocator that creates the surface. Can be NULL.surface: a pointer to a VkSurfaceKHR handle to output the newly created surface.
Return value
Returns true on success or false on failure; call SDL_GetError() for more
information.
Availability
This function is available since SDL 3.2.0.