pub unsafe extern "C" fn SDL_SetAtomicPointer(
a: *mut *mut c_void,
v: *mut c_void,
) -> *mut c_voidExpand description
Set a pointer to a value atomically.
Note: If you don’t know what this function is for, you shouldn’t use it!
Parameters
a: a pointer to a pointer.v: the desired pointer value.
Return value
Returns the previous value of the pointer.
Thread safety
It is safe to call this function from any thread.
Availability
This function is available since SDL 3.2.0.