pub unsafe extern "C" fn SDL_CloseCamera(camera: *mut SDL_Camera)Expand description
Use this function to shut down camera processing and close the camera device.
Parameters
camera: opened camera device.
Thread safety
It is safe to call this function from any thread, but no
thread may reference device once this function is called.
Availability
This function is available since SDL 3.2.0.