pub unsafe extern "C" fn SDL_GetCameraID(
camera: *mut SDL_Camera,
) -> SDL_CameraIDExpand description
Get the instance ID of an opened camera.
Parameters
camera: anSDL_Camerato query.
Return value
Returns the instance ID of the specified camera on success or 0 on
failure; call SDL_GetError() for more information.
Thread safety
It is safe to call this function from any thread.
Availability
This function is available since SDL 3.2.0.