pub unsafe extern "C" fn SDL_GetGamepadButtonLabelForType(
type: SDL_GamepadType,
button: SDL_GamepadButton,
) -> SDL_GamepadButtonLabelExpand description
Get the label of a button on a gamepad.
Parameters
type: the type of gamepad to check.button: a button index (one of theSDL_GamepadButtonvalues).
Return value
Returns the SDL_GamepadButtonLabel enum corresponding to the button label.
Thread safety
It is safe to call this function from any thread.
Availability
This function is available since SDL 3.2.0.