pub unsafe extern "C" fn SDL_GetGamepadMappingForGUID(
guid: SDL_GUID,
) -> *mut c_charExpand description
Get the gamepad mapping string for a given GUID.
Parameters
guid: a structure containing the GUID for which a mapping is desired.
Return value
Returns a mapping string or NULL on failure; call SDL_GetError() for more
information. This should be freed with SDL_free() when it is no
longer needed.
Thread safety
It is safe to call this function from any thread.
Availability
This function is available since SDL 3.2.0.