pub unsafe extern "C" fn SDL_GetGamepadStringForAxis(
axis: SDL_GamepadAxis,
) -> *const c_charExpand description
Convert from an SDL_GamepadAxis enum to a string.
Parameters
axis: an enum value for a givenSDL_GamepadAxis.
Return value
Returns a string for the given axis, or NULL if an invalid axis is
specified. The string returned is of the format used by
SDL_Gamepad mapping strings.
Thread safety
It is safe to call this function from any thread.
Availability
This function is available since SDL 3.2.0.