pub unsafe extern "C" fn SDL_RemoveHintCallback(
name: *const c_char,
callback: SDL_HintCallback,
userdata: *mut c_void,
)Expand description
Remove a function watching a particular hint.
Parameters
name: the hint being watched.callback: anSDL_HintCallbackfunction that will be called when the hint value changes.userdata: a pointer being passed to the callback function.
Thread safety
It is safe to call this function from any thread.
Availability
This function is available since SDL 3.2.0.