pub unsafe extern "C" fn SDL_SetHintWithPriority(
name: *const c_char,
value: *const c_char,
priority: SDL_HintPriority,
) -> boolExpand description
Set a hint with a specific priority.
The priority controls the behavior when setting a hint that already has a value. Hints will replace existing hints of their priority and lower. Environment variables are considered to have override priority.
Parameters
name: the hint to set.value: the value of the hint variable.priority: theSDL_HintPrioritylevel for the hint.
Return value
Returns true on success or false on failure; call SDL_GetError() for more
information.
Thread safety
It is safe to call this function from any thread.
Availability
This function is available since SDL 3.2.0.