pub type SDL_HintCallback = Option<unsafe extern "C" fn(userdata: *mut c_void, name: *const c_char, oldValue: *const c_char, newValue: *const c_char)>;Expand description
A callback used to send notifications of hint value changes.
This is called an initial time during SDL_AddHintCallback with the hint’s
current value, and then again each time the hint’s value changes. In the
initial call, the current value is in both oldValue and newValue.
Parameters
userdata: what was passed asuserdatatoSDL_AddHintCallback().name: what was passed asnametoSDL_AddHintCallback().oldValue: the previous hint value.newValue: the new value hint is to be set to.
Thread safety
This callback is fired from whatever thread is setting a new hint value. SDL holds a lock on the hint subsystem when calling this callback.
Availability
This datatype is available since SDL 3.2.0.
See also
Aliased Type
pub enum SDL_HintCallback {
None,
Some(unsafe extern "C" fn(*mut c_void, *const i8, *const i8, *const i8)),
}