Function SDL_HasScreenKeyboardSupport
Source pub unsafe extern "C" fn SDL_HasScreenKeyboardSupport() -> bool
Check whether the platform has screen keyboard support.
Return value
Returns true if the platform has some screen keyboard support or false if
not.
Thread safety
This function should only be called on the main thread.
Availability
This function is available since SDL 3.2.0.
See also