pub unsafe extern "C" fn SDL_UnloadObject(
handle: *mut SDL_SharedObject,
)Expand description
Unload a shared object from memory.
Note that any pointers from this object looked up through
SDL_LoadFunction() will no longer be valid.
Parameters
handle: a valid shared object handle returned bySDL_LoadObject().
Thread safety
It is safe to call this function from any thread.
Availability
This function is available since SDL 3.2.0.