pub unsafe extern "C" fn SDL_LogMessageV(
category: c_int,
priority: SDL_LogPriority,
fmt: *const c_char,
ap: VaList,
)Expand description
Log a message with the specified category and priority.
Parameters
category: the category of the message.priority: the priority of the message.fmt: a printf() style message format string.ap: a variable argument list.
Thread safety
It is safe to call this function from any thread.
Availability
This function is available since SDL 3.2.0.