pub unsafe extern "C" fn SDL_SetLogPriorityPrefix(
priority: SDL_LogPriority,
prefix: *const c_char,
) -> boolExpand description
Set the text prepended to log messages of a given priority.
By default SDL_LOG_PRIORITY_INFO and below have no prefix, and
SDL_LOG_PRIORITY_WARN and higher have a prefix showing their priority, e.g.
“WARNING: “.
This function makes a copy of its string argument, prefix, so it is not necessary to keep the value of prefix alive after the call returns.
Parameters
priority: theSDL_LogPriorityto modify.prefix: the prefix to use for that log priority, or NULL to use no prefix.
Return value
Returns true on success or false on failure; call SDL_GetError() for more
information.
Thread safety
It is safe to call this function from any thread.
Availability
This function is available since SDL 3.2.0.