pub unsafe extern "C" fn SDL_GetRectIntersectionFloat(
A: *const SDL_FRect,
B: *const SDL_FRect,
result: *mut SDL_FRect,
) -> boolExpand description
Calculate the intersection of two rectangles with float precision.
If result is NULL then this function will return false.
Parameters
A: anSDL_FRectstructure representing the first rectangle.B: anSDL_FRectstructure representing the second rectangle.result: anSDL_FRectstructure filled in with the intersection of rectanglesAandB.
Return value
Returns true if there is an intersection, false otherwise.
Thread safety
It is safe to call this function from any thread.
Availability
This function is available since SDL 3.2.0.