pub unsafe extern "C" fn SDL_HasRectIntersectionFloat(
A: *const SDL_FRect,
B: *const SDL_FRect,
) -> boolExpand description
Determine whether two rectangles intersect with float precision.
If either pointer is NULL the function will return false.
Parameters
A: anSDL_FRectstructure representing the first rectangle.B: anSDL_FRectstructure representing the second rectangle.
Return value
Returns true if there is an intersection, false otherwise.
Thread safety
It is safe to call this function from any thread.
Availability
This function is available since SDL 3.2.0.