pub extern "C" fn SDL_isgraph(x: c_int) -> c_intExpand description
Report if a character is any “printable” except space.
Be advised that “printable” has a definition that goes back to text terminals from the dawn of computing, making this a sort of special case function that is not suitable for Unicode (or most any) text management.
WARNING: Regardless of system locale, this is equivalent to
(SDL_isprint(x)) && ((x) != ' ').
Parameters
x: character value to check.
Return value
Returns non-zero if x falls within the character class, zero otherwise.
Thread safety
It is safe to call this function from any thread.
Availability
This function is available since SDL 3.2.0.