pub type SDL_malloc_func = Option<unsafe extern "C" fn(size: usize) -> *mut c_void>;Expand description
A callback used to implement SDL_malloc().
SDL will always ensure that the passed size is greater than 0.
Parameters
size: the size to allocate.
Return value
Returns a pointer to the allocated memory, or NULL if allocation failed.
Thread safety
It should be safe to call this callback from any thread.
Availability
This datatype is available since SDL 3.2.0.
See also
Aliased Type
pub enum SDL_malloc_func {
None,
Some(unsafe extern "C" fn(usize) -> *mut c_void),
}