pub unsafe extern "C" fn SDL_SetSurfaceColorMod(
surface: *mut SDL_Surface,
r: Uint8,
g: Uint8,
b: Uint8,
) -> boolExpand description
Set an additional color value multiplied into blit operations.
When this surface is blitted, during the blit operation each source color channel is modulated by the appropriate color value according to the following formula:
srcC = srcC * (color / 255)
Parameters
surface: theSDL_Surfacestructure to update.r: the red color value multiplied into blit operations.g: the green color value multiplied into blit operations.b: the blue color value multiplied into blit operations.
Return value
Returns true on success or false on failure; call SDL_GetError() for more
information.
Thread safety
This function can be called on different threads with different surfaces.
Availability
This function is available since SDL 3.2.0.