pub unsafe extern "C" fn SDL_SetSurfaceRLE(
surface: *mut SDL_Surface,
enabled: bool,
) -> boolExpand description
Set the RLE acceleration hint for a surface.
If RLE is enabled, color key and alpha blending blits are much faster, but the surface must be locked before directly accessing the pixels.
Parameters
surface: theSDL_Surfacestructure to optimize.enabled: true to enable RLE acceleration, false to disable it.
Return value
Returns true on success or false on failure; call SDL_GetError() for more
information.
Thread safety
This function can be called on different threads with different surfaces.
Availability
This function is available since SDL 3.2.0.