pub unsafe extern "C" fn SDL_WriteSurfacePixel(
surface: *mut SDL_Surface,
x: c_int,
y: c_int,
r: Uint8,
g: Uint8,
b: Uint8,
a: Uint8,
) -> boolExpand description
Writes a single pixel to a surface.
This function prioritizes correctness over speed: it is suitable for unit tests, but is not intended for use in a game engine.
Like SDL_MapRGBA, this uses the entire 0..255 range when converting color
components from pixel formats with less than 8 bits per RGB component.
Parameters
surface: the surface to write.x: the horizontal coordinate, 0 <= x < width.y: the vertical coordinate, 0 <= y < height.r: the red channel value, 0-255.g: the green channel value, 0-255.b: the blue channel value, 0-255.a: the alpha channel value, 0-255.
Return value
Returns true on success or false on failure; call SDL_GetError() for more
information.
Thread safety
This function can be called on different threads with different surfaces.
Availability
This function is available since SDL 3.2.0.