pub unsafe extern "C" fn SDL_ShowAndroidToast(
message: *const c_char,
duration: c_int,
gravity: c_int,
xoffset: c_int,
yoffset: c_int,
) -> boolExpand description
Shows an Android toast notification.
Toasts are a sort of lightweight notification that are unique to Android.
https://developer.android.com/guide/topics/ui/notifiers/toasts
Shows toast in UI thread.
For the gravity parameter, choose a value from here, or -1 if you don’t
have a preference:
https://developer.android.com/reference/android/view/Gravity
Parameters
message: text message to be shown.duration: 0=short, 1=long.gravity: where the notification should appear on the screen.xoffset: set this parameter only when gravity >=0.yoffset: set this parameter only when gravity >=0.
Return value
Returns true on success or false on failure; call SDL_GetError() for more
information.
Thread safety
It is safe to call this function from any thread.
Availability
This function is available since SDL 3.2.0.