pub unsafe extern "C" fn SDL_CreateTraySubmenu(
entry: *mut SDL_TrayEntry,
) -> *mut SDL_TrayMenuExpand description
Create a submenu for a system tray entry.
This should be called at most once per tray entry.
This function does the same thing as SDL_CreateTrayMenu, except that it
takes a SDL_TrayEntry instead of a SDL_Tray.
A menu does not need to be destroyed; it will be destroyed with the tray.
Parameters
entry: the tray entry to bind the menu to.
Return value
Returns the newly created menu.
Thread safety
This function should be called on the thread that created the tray.
Availability
This function is available since SDL 3.2.0.