Function SDL_GetNumVideoDrivers
Source pub unsafe extern "C" fn SDL_GetNumVideoDrivers() -> c_int
Get the number of video drivers compiled into SDL.
Return value
Returns the number of built in video drivers.
Thread safety
This function should only be called on the main thread.
Availability
This function is available since SDL 3.2.0.
See also