pub unsafe extern "C" fn SDL_GetWindowPixelFormat(
window: *mut SDL_Window,
) -> SDL_PixelFormatExpand description
Get the pixel format associated with the window.
Parameters
window: the window to query.
Return value
Returns the pixel format of the window on success or
SDL_PIXELFORMAT_UNKNOWN on failure; call SDL_GetError() for more
information.
Thread safety
This function should only be called on the main thread.
Availability
This function is available since SDL 3.2.0.