pub unsafe extern "C" fn SDL_GetWindowProgressValue(
window: *mut SDL_Window,
) -> c_floatExpand description
Get the value of the progress bar for the given window’s taskbar icon.
Parameters
window: the window to get the current progress value from.
Return value
Returns the progress value in the range of [0.0f - 1.0f], or -1.0f on
failure; call SDL_GetError() for more information.
Thread safety
This function should only be called on the main thread.
Availability
This function is available since SDL 3.4.0.